==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/sl.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Nastavitve so posodobljene.",
"Activity" => "Dejavnosti",
"A file or folder has been <strong>shared</strong>" => "Za datoteko ali mapo je odobrena <strong>souporaba</strong>.",
"A new file or folder has been <strong>created</strong> in a shared folder" => "V mapi, določeni za souporabo, je bila <strong>ustvarjena</strong> datoteka.",
"A file or folder has been <strong>changed</strong> in a shared folder" => "V mapi, določeni za souporabo, je bila <strong>spremenjena</strong> datoteka.",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "V mapi, določeni za souporabo, je bila <strong>izbrisana</strong> datoteka.",
"You created %1\$s" => "Ustvarili ste %1\$s",
"%2\$s created %1\$s" => "%2\$s je ustvaril %1\$s",
"You changed %1\$s" => "Spremenili ste %1\$s",
"%2\$s changed %1\$s" => "%2\$s je spremenil %1\$s",
"You deleted %1\$s" => "Izbrisali ste %1\$s",
"%2\$s deleted %1\$s" => "%2\$s je izbrisal %1\$s",
"You shared %1\$s with %2\$s" => "Omogočili ste souporabo %1\$s z uporabnikom %2\$s",
"You shared %1\$s with group %2\$s" => "Omogočili ste souporabo %1\$s s skupino %2\$s",
"%2\$s shared %1\$s with you" => "Uporabnik %2\$s je omogočil souporabo %1\$s",
"You shared %1\$s via link" => "Omogočili ste souporabo %1\$s preko povezave",
"Activity notification" => "Obvestila o dejavnosti",
"All Activities" => "Vse dejavnosti",
"Activities by you" => "Vaše dejavnosti",
"Activities by others" => "Dejavnosti drugih",
"Shares" => "Souporaba",
"Files" => "Datoteke",
"%s and %s" => "%s in %s",
", " => ",",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s in <strong class=\"tooltip\" title=\"%s\">%n več</strong>","%s in <strong class=\"tooltip\" title=\"%s\">%n več</strong>","%s in <strong class=\"tooltip\" title=\"%s\">%n več</strong>","%s in <strong class=\"tooltip\" title=\"%s\">%n več</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s in %n več","%s in %n več","%s in %n več","%s in %n več"),
"Hello %s," => "Pozdravljeni, %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "V zadnji uri so potekale naslednje dejavnosti na %s",
"You are receiving this email because in the last day the following things happened at %s" => "V zadnjem dnevu so potekale naslednje dejavnosti na %s",
"You are receiving this email because in the last week the following things happened at %s" => "V zadnjem tednu so potekale naslednje dejavnosti na %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Tu bo izpisan seznam dogodkov, ko bo %s v uporabi.",
"No more events to load" => "Ni več dogodkov za nalaganje",
"Enable RSS feed" => "Omogoči vire RSS",
"Notifications" => "Obvestila",
"Mail" => "Elektronska pošta",
"Stream" => "Pretok",
"You need to set up your email address before you can receive notification emails." => "Za prejemanje obvestil z elektronsko pošto, je treba najprej nastaviti elektronski poštni naslov.",
"Send emails:" => "Pošlji elektronsko sporočilo:",
"Hourly" => "Vsako uro",
"Daily" => "Dnevno",
"Weekly" => "Tedensko",
"Activity feed" => "Objava dejavnosti z viri RSS",
"Personal activity feed for %s" => "Osebne dejavnosti za %s"
);
$PLURAL_FORMS = "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/sl.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Nastavitve so posodobljene.",
"Activity" => "Dejavnosti",
"A file or folder has been <strong>shared</strong>" => "Za datoteko ali mapo je odobrena <strong>souporaba</strong>.",
"A new file or folder has been <strong>created</strong>" => "Nova datoteka ali mapa je <strong>ustvarjena</strong>",
"A file or folder has been <strong>changed</strong>" => "Datoteka ali mapa je <strong>spremenjena</strong>.",
"A file or folder has been <strong>deleted</strong>" => "Datoteka ali mapa je <strong>izbrisana</strong>.",
"You created %1\$s" => "Ustvarili ste %1\$s",
"%2\$s created %1\$s" => "%2\$s je ustvaril %1\$s",
"You changed %1\$s" => "Spremenili ste %1\$s",
"%2\$s changed %1\$s" => "%2\$s je spremenil %1\$s",
"You deleted %1\$s" => "Izbrisali ste %1\$s",
"%2\$s deleted %1\$s" => "%2\$s je izbrisal %1\$s",
"You shared %1\$s with %2\$s" => "Omogočili ste souporabo %1\$s z uporabnikom %2\$s",
"You shared %1\$s with group %2\$s" => "Omogočili ste souporabo %1\$s s skupino %2\$s",
"%2\$s shared %1\$s with you" => "Uporabnik %2\$s je omogočil souporabo %1\$s",
"You shared %1\$s via link" => "Omogočili ste souporabo %1\$s preko povezave",
"Activity notification" => "Obvestila o dejavnosti",
"All Activities" => "Vse dejavnosti",
"Activities by you" => "Vaše dejavnosti",
"Activities by others" => "Dejavnosti drugih",
"Shares" => "Souporaba",
"Files" => "Datoteke",
"%s and %s" => "%s in %s",
", " => ",",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s in <strong class=\"tooltip\" title=\"%s\">%n več</strong>","%s in <strong class=\"tooltip\" title=\"%s\">%n več</strong>","%s in <strong class=\"tooltip\" title=\"%s\">%n več</strong>","%s in <strong class=\"tooltip\" title=\"%s\">%n več</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s in %n več","%s in %n več","%s in %n več","%s in %n več"),
"Hello %s," => "Pozdravljeni, %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "V zadnji uri so potekale naslednje dejavnosti na %s",
"You are receiving this email because in the last day the following things happened at %s" => "V zadnjem dnevu so potekale naslednje dejavnosti na %s",
"You are receiving this email because in the last week the following things happened at %s" => "V zadnjem tednu so potekale naslednje dejavnosti na %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Tu bo izpisan seznam dogodkov, ko bo %s v uporabi.",
"No more events to load" => "Ni več dogodkov za nalaganje",
"Enable RSS feed" => "Omogoči vire RSS",
"Notifications" => "Obvestila",
"Mail" => "Elektronska pošta",
"Stream" => "Pretok",
"Notify about my own actions" => "Obveščaj me tudi o mojih dejanjih",
"You need to set up your email address before you can receive notification emails." => "Za prejemanje obvestil z elektronsko pošto, je treba najprej nastaviti elektronski poštni naslov.",
"Send emails:" => "Pošlji elektronsko sporočilo:",
"Hourly" => "Vsako uro",
"Daily" => "Dnevno",
"Weekly" => "Tedensko",
"Activity feed" => "Objava dejavnosti z viri RSS",
"Personal activity feed for %s" => "Osebne dejavnosti za %s"
);
$PLURAL_FORMS = "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);";
